#include <iostream>
#include <vector>
#include <limits>   // Для numeric_limits
#include <algorithm> // Для std::min

using namespace std;

bool isWoodenMatrix(int n, const vector<vector<int>>& matrix) {
    // Создаем копию матрицы для работы с алгоритмом Флойда-Уоршелла
    vector<vector<int>> dist = matrix;

    // Алгоритм Флойда-Уоршелла
    for (int k = 0; k < n; ++k) {
        for (int i = 0; i < n; ++i) {
            for (int j = 0; j < n; ++j) {
                // Обновляем расстояние, если найдено более короткое
                if (dist[i][k] < numeric_limits<int>::max() && dist[k][j] < numeric_limits<int>::max()) {
                    dist[i][j] = min(dist[i][j], dist[i][k] + dist[k][j]);
                }
            }
        }
    }

    // Проверка на совпадение расстояний
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            if (dist[i][j] != matrix[i][j]) {
                return false;
            }
        }
    }
    return true;
}

int main() {
    int n;
    cin >> n;

    vector<vector<int>> matrix(n, vector<int>(n));
    
    // Чтение матрицы
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            cin >> matrix[i][j];
        }
    }

    // Проверка на нули и положительные значения
    for (int i = 0; i < n; ++i) {
        if (matrix[i][i] != 0) {
            cout << "No" << endl;
            return 0;
        }
        for (int j = 0; j < n; ++j) {
            if (i != j && matrix[i][j] <= 0) {
                cout << "No" << endl;
                return 0;
            }
        }
    }

    // Проверка на неравенство треугольника
    if (isWoodenMatrix(n, matrix)) {
        cout << "Yes" << endl;
    } else {
        cout << "No" << endl;
    }

    return 0;
}