#include <iostream>
#include <algorithm>
#include <vector>
#include <iomanip>
#include <map>
#include <set>
#include <fstream>
#include <string>
#include <bitset>
#include <ctime>
#include <random>
#include <iterator>
#include <cmath>
#include <queue>
#include <deque>
#include <time.h>
 
using namespace std;
 
#define all(a) a.begin(), a.end()
#define rsort(a) sort(a, [&](auto b, auto c) {return b > c;})
 
ifstream fin("input.txt");
ofstream fout("output.txt");
 
using ll = long long;
using ld = long double;
using ull = unsigned long long;
 
ll const inf = 1e18;
 
template <class T>
istream& operator>> (istream& in, vector<T>& a)
{
	for (T& e : a)
		in >> e;
	return in;
}
 
template <class T>
ostream& operator<< (ostream& out, const vector<T>& a)
{
	for (const T& e : a)
		out << e << " ";
	return out;
}
 
template<class T, class N> auto min(T a, N b)
{
	return sizeof(a) > sizeof(b) ? min(a, (T)b) : min((N)a, b);
}
 
template<class T, class N> auto max(T a, N b)
{
	return sizeof(a) > sizeof(b) ? max(a, (T)b) : max((N)a, b);
}
 
const ll mod = 998244353;
 
ll bin_pow_mod(ll a, ll n)
{
	ll res = 1;
	while (n)
	{
		if (n & 1)
		{
			res *= a;
			res %= mod;
		}
 
		n >>= 1;
		a *= a;
		a %= mod;
	}
 
	return res;
}
 
ll bin_pow(ll a, ll n)
{
	ll res = 1;
	while (n)
	{
		if (n & 1)
		{
			res *= a;
		}
 
		n >>= 1;
		a *= a;
	}
 
	return res;
}
 
ll gcd(ll a, ll b)
{
	while (b)
	{
		a %= b;
		swap(a, b);
	}
	return a;
}



struct SegmentTreeMass
{
	struct Node
	{
		ll sum = 0;
		ll add = 0;

		Node(ll Sum = 0, ll Add = 0)
		{
			sum = Sum;
			add = Add;
		}
	};

	Node neutral = Node();
	ll n;
	vector<Node> tree;

	SegmentTreeMass(vector<ll>& start)
	{
		n = start.size();
		tree.resize(4 * n + 3);
		init(start);
	}

	SegmentTreeMass(ll N)
	{
		n = N;
		tree.resize(4 * n + 3);
		vector<ll> start(n, 0);
		init(start);
	}

	Node merge(Node n1, Node n2)
	{
		return Node(n1.sum + n2.sum);
	}

	void fix(ll v, ll l, ll r)
	{
		tree[v] = merge(tree[v * 2 + 1], tree[v * 2 + 2]);
	}

	void apply(ll v, ll l, ll r, ll val)
	{
		tree[v].add += val;
		tree[v].sum += val * (r - l);
	}

	void init(ll v, ll l, ll r, vector<ll>& start)
	{
		if (l + 1 == r)
		{
			tree[v] = Node(start[l], 0);
			return;
		}

		ll m = (r + l) / 2;
		init(v * 2 + 1, l, m, start);
		init(v * 2 + 2, m, r, start);
		fix(v, l, r);
	}

	void init(vector<ll>& start)
	{
		init(0, 0, n, start);
	}

	void push(ll v, ll l, ll r)
	{
		ll m = (r + l) / 2;

		apply(v * 2 + 1, l, m, tree[v].add);
		apply(v * 2 + 2, m, r, tree[v].add);
		tree[v].add = 0;
	}

	// [l: r)
	Node query(ll v, ll l, ll r, ll ql, ll qr)
	{
		if (ql <= l && r <= qr)
		{
			return tree[v];
		}
		if (r <= ql || qr <= l)
		{
			return neutral;
		}

		ll m = (r + l) / 2;
		push(v, l, r);
		return merge(
			query(v * 2 + 1, l, m, ql, qr),
			query(v * 2 + 2, m, r, ql, qr));

	}

	Node query(ll ql, ll qr)
	{
		return query(0, 0, n, ql, qr);
	}

	void add(ll v, ll l, ll r, ll ql, ll qr, ll val)
	{
		if (ql <= l && r <= qr)
		{
			apply(v, l, r, val);
			return;
		}
		if (r <= ql || qr <= l)
		{
			return;
		}

		ll m = (r + l) / 2;
		push(v, l, r);
		add(v * 2 + 1, l, m, ql, qr, val);
		add(v * 2 + 2, m, r, ql, qr, val);
		fix(v, l, r);
	}

	void add(ll ql, ll qr, ll val)
	{
		add(0, 0, n, ql, qr, val);
	}

};
 
random_device rd;
mt19937 mersenne(rd());

void solve();
 
// #define TIME
// #define ONCE
 
signed main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
 
	ll TT = 1;
#ifndef ONCE 
	cin >> TT;
#endif
	while (TT--)
	{
#ifdef TIME
		clock_t start, end;
 
		start = clock();
#endif
		solve();
#ifdef TIME
		end = clock();
 
		cerr << "\ntime: " << ((double)end - start) / ((double)CLOCKS_PER_SEC) << " s\n";
#endif
		cerr << '\n';
	}
	return 0;
}

ll true_mod(ll a, ll m) {
	if (m < 0) {
		m *= -1;
	}
	return ((a % m) + m) % m;
}
ll true_div(ll a, ll m) {
	return (a - true_mod(a , m)) / m;
}

void solve() 
{
	string s; ll k;
	cin >> s >> k;
	ll n = s.size();
	vector<ll> start(n, 0);
	SegmentTreeMass stm(start);
	vector<vector<ll>> indices(10, vector<ll>(0));
	for (int i = n - 1; i >= 0; --i)
	{
		indices[s[i] - '0'].push_back(i);
	}
	ll cur = 0;
	while (cur < n)
	{
		cur = n;
		for (int i = 1; i < 10; ++i)
		{
			if (!indices[i].empty())
			{
				cur = min(cur, indices[i].back());
			}
		}
		if (cur == n)
		{
			break;
		}
		ll t = cur; // swap cur and t
		ll cost = inf; // swap cost

		ll curpos = (cur + stm.query(cur, cur+1).sum);
		for (int i = 9; i >= 1; --i)
		{
			if (!indices[i].empty())
			{
				ll tc = indices[i].back();
				ll swapc = (tc + stm.query(tc, tc+1).sum) - curpos;
				if (swapc <= k)
				{
					t = tc;
					cost = swapc;
				}
			}
		}

		cout << s[t];
		k -= cost;
		stm.add(cur, t, 1);
		ll d = s[t] - '0'; // swapped_elem
		indices[d].pop_back();
	}
	cout << '\n';
}
