#include "bits/stdc++.h"

using namespace std;

using ll = long long;
using ld = long double;
using lll = long long;

struct rat{
    lll p = 0, q = 1;

    rat(lll a = 0, lll b = 1){
        p = a, q = b;
        fix();
    }

    void fix(){
        lll g = gcd(abs(p), abs(q));
        if(g){
            p /= g;
            q /= g;
        }
        if(q < 0){
            p = -p;
            q = -q;
        }
    }

    rat operator+(rat other) const{
        lll g = gcd(abs(other.q), abs(q));
        other.q/=g;
        rat res = {p*other.q + (q/g)*other.p, q * other.q};
        res.fix();
        return res;
    }

    rat operator+=(rat other){
        rat res = *this + other;
        swap(res, *this);
        return *this;
    }

    rat operator-(rat other) const{
        other.p = -other.p;
        return *this + other;
    }

    rat operator-=(rat other){
        rat res = *this - other;
        swap(res, *this);
        return *this;
    }

    rat operator*(rat other) const{
        lll g1 = gcd(abs(p), other.q), g2 = gcd(abs(other.p), q);
        other.p /= g2, other.q /= g1;
        rat res = {(p/g1)*other.p, (q/g2)*other.q};
        return res;
    }

    rat operator*=(rat other){
        rat res = *this * other;
        swap(p, res.p), swap(q, res.q);
        return *this;
    }

    rat operator/=(rat other){
        swap(other.p, other.q);
        other.fix();
        *this *= other;
        return *this;
    }

    ld to_ld() const{
        return ld(p) / ld(q);
    }
};

ostream& operator<<(ostream& ostr, rat r){
    ostr<<ll(r.p)<<"/"<<ll(r.q);
    return ostr;
}

typedef rat num;

template<typename T, int n>
struct polynom{
    array<T, n> a;

    T& operator[](int i){
        return a[i];
    }

    polynom operator+=(polynom b){
        for (int i = 0; i < n; ++i) {
            a[i] += b[i];
        }
        return *this;
    }

    polynom operator+(polynom b) const{
        polynom res = *this;
        res += b;
        return res;
    }

    polynom operator-=(polynom b){
        for (int i = 0; i < n; ++i) {
            a[i] -= b[i];
        }
        return *this;
    }

    polynom operator-(polynom b) const{
        polynom res = *this;
        res -= b;
        return res;
    }

    polynom operator*(polynom b) const{
        polynom res;
        for (int i = 0; i < n; ++i) {
            for(int j = 0; j + i < n; ++j){
                res[i + j] += a[i] * b[j];
            }
        }
        return res;
    }

    polynom operator*=(polynom b){
        polynom res = *this * b;
        swap(*this, res);
        return *this;
    }

    polynom operator/=(T p){
        for (int i = 0; i < n; ++i) {
            a[i] /= p;
        }
        return *this;
    }

    polynom operator/(T p) const{
        polynom res = *this;
        res /= p;
        return res;
    }

    polynom operator*=(T p){
        for (int i = 0; i < n; ++i) {
            a[i] *= p;
        }
        return *this;
    }

    polynom operator*(T p) const{
        polynom res = *this;
        res *= p;
        return res;
    }

    polynom operator<<(int k) const{
        polynom res = *this;
        for (int i = n-1; i >= k; --i) {
            res.a[i] = res.a[i-k];
        }
        for (int i = 0; i < k; ++i) {
            res.a[i] = 0;
        }
        return res;
    }

    ld evaluate(ld x) const{
        //cout<<x<<" in "<<*this<<" =\n";
        ld res = 0;
        for (int i = n - 1; i >= 0; --i) {
            res = (res * x) + a[i].to_ld();
        }
        //cout<<res<<endl;
        return res;
    }

};

struct rng{
    ll mn = INT_MIN, mx = INT_MAX;

    void operator+=(rng b){
        mx = min(mx, b.mx);
        mn = max(mn, b.mn);
    }
};

typedef polynom<num, 64> pol;

ostream& operator<<(ostream& ostr, pol x){
    for (int i = 0; i < x.a.size(); ++i) {
        cout<<x[i]<<" ";
    }
    return ostr;
}

vector<vector<ld>> t;
int pr = 100000;

void precalc() {
    int n = 64;
    t.resize(n);
    for (int i = 0; i < n; ++i) {
        t[i].resize(pr);
        t[i][0] = (i+1)%2;
    }
    for(int j = 0; j < pr; ++j){
        t[0][j] = 1;
    }
    for (int i = 1; i < n; ++i) {
        for (int j = 1; j < pr; ++j) {
            t[i][j] = t[i-1][j-1] + t[i][j-1];
        }
    }
}

void solve(){
    ll n, k;
    cin>>n>>k;
    if(n == 1){
        cout<<0<<"\n";
        return;
    }
    if(k > 31){
        int ans = 0;
        --n;
        while(n > 0){
            ++ans;
            n /= 2;
        }
        cout<<ans<<"\n";
        return;
    }
    if(k == 1) {
        --n;
        n = 8*n+1;
        ll sq = llround(sqrt(n));
        if(sq * sq == n) {
            cout << (sq / 2) << "\n";
            return;
        }
        cout << llround(ceil((1 + sqrt(n))/2)) - 1 << "\n";
        return;
    }
    ll l = 0, r = pr;
    while (r - l > 1) {
        ll m = (l + r) / 2;
        if (t[2*k][m] >= n) {
            r = m;
        } else {
            l = m;
        }
    }
    cout << l << "\n";
}

int main() {
    std::ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    precalc();
    int n = 1;
    cin>>n;
    while(n--)
        solve();
}