#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <set>
#include <map>
#include <algorithm>
#include <vector>
#include <string>
#include <queue>
#include <climits>

using namespace std;

struct SegmentTree {
    vector<int> sum;
    vector<int> modif;
    int n = 0;

    void push(int pos) {
        modif[pos * 2] += modif[pos];
        modif[pos * 2 + 1] += modif[pos];
        modif[pos] = 0;
    }

    SegmentTree(const vector<int>& v) {
        n = 1;
        while (n < v.size())
            n *= 2;
        sum.resize(n * 2, 0);
        modif.resize(n * 2, 0);
        for (int i = 0; i < v.size(); i++)
            sum[i + n] = v[i];

        for (int i = n - 1; i > 0; i--)
            sum[i] = sum[i * 2] + sum[i * 2 + 1];
    }

    long long getSum(int l, int r) {
        return getSum(l, r, 0, n - 1, 1);
    }

    long long getSum(int l, int r, int lt, int rt, int pos) {
        if (rt < l || lt > r)
            return 0;
        if (lt >= l && rt <= r)
            return sum[pos];

        push(pos);

        int mid = (lt + rt) / 2;
        return getSum(l, r, lt, mid, pos * 2) + getSum(l, r, mid + 1, rt, pos * 2 + 1);
    }

    void subseg_add(int l, int r, int val) {
        subseg_add(l, r, val, 0, n - 1, 1);
    }

    void subseg_add(int l, int r, int val, int lt, int rt, int pos) {
        if (rt < l || lt > r)
            return;
        if (lt >= l && rt <= r) {
            modif[pos] += val;
            return;
        }

        push(pos);

        int mid = (lt + rt) / 2;
        subseg_add(l, r, val, lt, mid, pos * 2);
        subseg_add(l, r, val, mid + 1, rt, pos * 2 + 1);
    }

    long long getVal(int x) {
        int pos = 1;
        int l = 0, r = n - 1;
        while (l < x || r > x) {
            int mid = (l + r) / 2;

            push(pos);

            if (mid >= x) {
                r = mid;
                pos = pos * 2;
            }
            else {
                l = mid + 1;
                pos = pos * 2 + 1;
            }
        }
        return sum[pos] + modif[pos];
    }
};

void resolve() {
    string s;
    cin >> s;
    long long k;
    cin >> k;
    SegmentTree shifted(vector<int>(s.size(), 0));
    set<pair<int, int>> minDigits;

    int r = (int)min(k + 1, (long long)s.size());
    for (int i = 0; i < r; i++)
        minDigits.insert({ s[i] - '0', i });
    for (int l = 0; l < s.size(); l++) {
        auto minDigit = *minDigits.begin();
        minDigits.erase(minDigits.begin());
        cout << minDigit.first;
        int shiftedBetween = shifted.getSum(l + 1, minDigit.second - 1);
        if (shiftedBetween == 0 && r < s.size()) {
            minDigits.insert({ s[r] - '0', r });
            r++;
        } else {
            for (int i = r - 1; i > r - shiftedBetween - 1; i--)
                minDigits.erase({ s[i] - '0', i });
            r -= shiftedBetween;
        }
    }
    cout << '\n';
}

int main()
{
#ifdef _DEBUG
    freopen("input.txt", "r", stdin);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    int t;
    cin >> t;

    for (int i = 0; i < t; i++)
        resolve();
    return 0;
};