#include <iostream>
#include <unordered_map>
#include <array>

const int MOD = 998244353;

struct State {
    int r, g, b;
    char lastColor;

    bool operator==(const State& other) const {
        return r == other.r && g == other.g && b == other.b && lastColor == other.lastColor;
    }
};

namespace std {
    template <>
    struct hash<State> {
        std::size_t operator()(const State& state) const {
            return ((std::hash<int>()(state.r) ^ (std::hash<int>()(state.g) << 1)) >> 1) ^ (std::hash<int>()(state.b) << 2) ^ std::hash<char>()(state.lastColor);
        }
    };
}

std::unordered_map<State, int> dp;

inline int mod(int x) {
    return (x % MOD + MOD) % MOD;
}

int countW(int r, int g, int b, char lastColor) {
    if (r == 0 && g == 0 && b == 0) {
        return 1;
    }

    State state{ r, g, b, lastColor };
    if (dp.find(state) != dp.end()) {
        return dp[state];
    }

    int way = 0;
    if (r > 0 && lastColor != 'R') {
        way = mod(way + countW(r - 1, g, b, 'R'));
    }
    if (g > 0 && lastColor != 'G') {
        way = mod(way + countW(r, g - 1, b, 'G'));
    }
    if (b > 0 && lastColor != 'B') {
        way = mod(way + countW(r, g, b - 1, 'B'));
    }

    dp[state] = way;
    return way;
}

int main() {
    int r, g, b;
    std::cin >> r >> g >> b;

    int result = countW(r, g, b, '\0');
    std::cout << result << std::endl;

    return 0;
}
