#include <limits>
#pragma GCC optimize("O3,Ofast")
#include <bits/stdc++.h>

using namespace std;

template<typename A, typename B> ostream& operator<<(ostream &os, const pair<A, B> &p) { return os << '(' << p.first << ", " << p.second << ')'; }
template<typename T_container, typename T = typename enable_if<!is_same<T_container, string>::value, typename T_container::value_type>::type> ostream& operator<<(ostream &os, const T_container &v) { os << '{'; string sep; for (const T &x : v) os << sep << x, sep = ", "; return os << '}'; }
void dbg_out() { cerr << endl; }
template<typename Head, typename... Tail> void dbg_out(Head H, Tail... T) { cerr << ' ' << H; dbg_out(T...); }
#ifdef LOCAL
#define dbg(...) cerr << "(" << #__VA_ARGS__ << "):", dbg_out(__VA_ARGS__)
#else
#define dbg(...)
#endif

#define ll long long
#define ld long double
#define all(a) (a).begin(), (a).end()

const int MAX_N = 1e5 + 5;
const ll MOD = 1e9 + 7;
const ll INF = 1e9;
const ld EPS = 1e-9;


struct Graph {
    struct Edge {
        int next;
        int to;
        int weight;
    };

    std::vector<int> head;
    std::vector<Edge> edges;
    int edges_count;

    Graph(int vertices, int max_edges)
    : head(vertices, -1), edges(max_edges), edges_count{0} {
    }

    struct AdjacencyIterator {
        std::vector<Edge> &edges;
        int edge;

        AdjacencyIterator(std::vector<Edge> &graph_edges, int current_edge)
        : edges(graph_edges), edge(current_edge) {
        }

        Edge &operator*() const {
            return edges[edge];
        }

        Edge *operator->() const {
            return &edges[edge];
        }

        AdjacencyIterator &operator++() {
            edge = edges[edge].next;
            return *this;
        }

        AdjacencyIterator operator++(int) {
            AdjacencyIterator tmp = *this;
            edge = edges[edge].next;
            return tmp;
        }

        friend bool operator==(
            const AdjacencyIterator &lhs, const AdjacencyIterator &rhs
        ) {
            return lhs.edge == rhs.edge;
        }

        friend bool operator!=(
            const AdjacencyIterator &lhs, const AdjacencyIterator &rhs
        ) {
            return lhs.edge != rhs.edge;
        }

        AdjacencyIterator begin() {
            return *this;
        }

        AdjacencyIterator end() {
            return AdjacencyIterator(edges, -1);
        }
    };

    AdjacencyIterator Adj(int v) {
        return AdjacencyIterator(edges, head[v]);
    }

    void AddEdge(int a, int b, int w) {
        assert(edges_count != edges.size());
        edges[edges_count] = {head[a], b, w};
        head[a] = edges_count++;
    }

    void Dijkstra(int src, int target) {
        int n = head.size();

        vector<ll> d(n);
        vector<pair<ll, ll>> parent(n);
        parent[src] = {-1, -1};

        fill(all(d), numeric_limits<ll>::max());
        d[src] = 0;

        priority_queue<pair<int, int>, vector<pair<int, int>>,
                       greater<pair<int, int>>>
            Q;
        Q.push(make_pair(0, src));

        while (!Q.empty()) {
            pair<int, int> node = Q.top();
            Q.pop();

            if (node.first > d[node.second])
                continue;

            for (int i = head[node.second]; i != -1; i = edges[i].next) {
                auto &e = edges[i];
                int u = node.second;
                int v = e.to;
                if (d[v] > d[u] + 1) {
                    d[v] = d[u] + 1;
                    Q.push(make_pair(d[v], v));
                    parent[v] = {u, e.weight};
                }
            }
        }

        dbg(d);

        if (d[target] == numeric_limits<ll>::max()) {
            cout << "Impossible" << '\n';
            return;
        }

        vector<ll> path;
        path.reserve(d[target]);
        while(parent[target].first != -1) {
            path.push_back(target);
            target = parent[target].first;
        }
        path.push_back(target);

        reverse(all(path));

        dbg(path, parent);

        for (ll i = 1; i < path.size(); ++i) {
            if (parent[path[i]].second == 0) {
                parent[path[i]].second = 2;
            }
            cout << "Kaban-" << parent[path[i]].second << ' ' << path[i-1] + 1 << ' ' << path[i] + 1 << '\n';
        }
    }
};


void solve() {
    ll n;
    cin >> n;

    ll s, t;
    vector<ll> a(n);
    vector<ll> modules(n);
    for (ll i = 0; i < n; ++i) {
        cin >> a[i];
    }

    cin >> s >> t;

    if (s == t) {
        return;
    }

    s--;
    t--;
    Graph g(n, 10*n);


    ll prev = abs(a[s+1] - a[s]);
    ll l = s;
    for (ll i = s+2; i < n; ++i) {
        if (prev == 1) {
            prev = abs(a[i] - a[i-1]);
            l = i - 1;
            continue;
        }
        ll curgcd = __gcd(abs(a[i] - a[i-1]), prev);
        if (curgcd == 1) {
            if (i - 2 != l) {
                g.AddEdge(l, i-1, prev);
                g.AddEdge(i-1, l, prev);
                if (l <= s && s <= i-1) {
                    g.AddEdge(l, s, prev);
                    g.AddEdge(s, l, prev);
                    g.AddEdge(s, i-1, prev);
                    g.AddEdge(i-1, s, prev);
                }
                if (l <= t && t <= i-1) {
                    g.AddEdge(l, t, prev);
                    g.AddEdge(t, l, prev);
                    g.AddEdge(t, i-1, prev);
                    g.AddEdge(i-1, t, prev);
                }
                if (l <= s && s <= i-1 && t && l <= t && t <= i - 1) {
                    g.AddEdge(s, t, prev);
                    g.AddEdge(t, s, prev);
                }
            }
            prev = abs(a[i] - a[i-1]);
            l = i - 1;
        } else {
            prev = curgcd;
        }
    }

    ll i = n;
    if (i - 2 > l && prev != 1) {
        dbg(l, i-1);
        g.AddEdge(l, i-1, prev);
        g.AddEdge(i-1, l, prev);
        if (l <= s && s <= i-1) {
            g.AddEdge(l, s, prev);
            g.AddEdge(s, l, prev);
            g.AddEdge(s, i-1, prev);
            g.AddEdge(i-1, s, prev);
        }
        if (l <= t && t <= i-1) {
            g.AddEdge(l, t, prev);
            g.AddEdge(t, l, prev);
            g.AddEdge(t, i-1, prev);
            g.AddEdge(i-1, t, prev);
        }
        if (l <= s && s <= i-1 && t && l <= t && t <= i - 1) {
            g.AddEdge(s, t, prev);
        }

    }

    for (ll i = 1; i < n; ++i) {
        ll weight = abs(a[i] - a[i-1]);
        if (weight == 1) {
            continue;
        }
        g.AddEdge(i, i-1, weight);
        g.AddEdge(i-1, i, weight);
    }


    g.Dijkstra(s, t);
}

int main() {
    ios_base::sync_with_stdio(0);
    cin.tie(0); cout.tie(0);
    int tc = 1;
    // cin >> tc;
    for (int t = 1; t <= tc; t++) {
        // cout << "Case #" << t << ": ";
        solve();
    }
}
