import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.*;
import java.util.stream.Collectors;

public class Main {
    public static HashMap<String, Integer> seenWhite = new HashMap<>();
    public static HashMap<String, Integer> seenBlack = new HashMap<>();
    public static HashSet<String> gotten = new HashSet<>();

    public static HashMap<String, Set<String>> forCamel = new HashMap<>();
    public static HashMap<String, Set<String>> forVizir = new HashMap<>();
    public static HashMap<String, Set<String>> forKing = new HashMap<>();

    public static boolean valid(String place) {
        return place.charAt(0) >= 'a' && place.charAt(0) <= 'h'
            && place.charAt(1) >= '1' && place.charAt(1) <= '8';
    }

    public static String add(String place, int dx, int dy) {
        char a = (char)(place.charAt(0) + dx);
        char b = (char)(place.charAt(1) + dy);
        return a + "" + b;
    }

    public static Set<String> camel(String place) {
        return Set.of(
                add(place, -1, -3),
                add(place, -1, 3),
                add(place, 1, -3),
                add(place, 1, 3),
                add(place, 3, -1),
                add(place, 3, 1),
                add(place, -3, -1),
                add(place, -3, 1)
        ).stream().filter(Main::valid).collect(Collectors.toSet());
    }

    public static Set<String> vizir(String place) {
        return Set.of(
                add(place, -1, 0),
                add(place, 1, 0),
                add(place, 0, -1),
                add(place, 0, 1)
        ).stream().filter(Main::valid).collect(Collectors.toSet());
    }

    public static Set<String> king(String place) {
        Set<String> result = new HashSet<>();
        for (int dx = -1; dx <= 1; dx++) {
            for (int dy = -1; dy <= 1; dy++) {
                if (dx == 0 && dy == 0) {
                    continue;
                }
                String res = add(place, dx, dy);
                if (valid(res)) {
                    result.add(res);
                }
            }
        }
        return result;
    }

    public static String toPlace(int x, int y) {
        char a = (char)('a' + x);
        char b = (char)('1' + y);
        return a + "" + b;
    }

    public static boolean allDifferent(String a, String b, String c, String d) {
        return !Objects.equals(a, b) && !Objects.equals(a, c) && !Objects.equals(a, d) && !Objects.equals(b, c) && !Objects.equals(b, d) && !Objects.equals(c, d);
    }

    public static boolean okKings(String a, String b) {
        return !forKing.get(a).contains(b);
    }

    public static boolean check(String wCamel, String wVizir, String bKing) {
        return forCamel.get(wCamel).contains(bKing) || forVizir.get(wVizir).contains(bKing);
    }

    public static boolean canGo(String wKing, String bKing, String wCamel, String wVizir, String turn) {
        String str = wKing + " " + bKing + " " + wCamel + " " + wVizir;
        if (Objects.equals(turn, "w")) {
            return seenWhite.containsKey(str) || !gotten.contains(str);
        } else {
            return seenBlack.containsKey(str) || !gotten.contains(str);
        }
    }

    public static int addd(int a, int b) {
        if (a == Integer.MAX_VALUE) {
            return a;
        }
        if (b == Integer.MAX_VALUE) {
            return b;
        }
        return a + b;
    }

    public static int dist(String a, String b) {
        char a0 = a.charAt(0);
        char a1 = a.charAt(1);
        char b0 = b.charAt(0);
        char b1 = b.charAt(1);
        return Math.max(
                Math.max(a0, b0) - Math.min(a0, b0),
                Math.max(a1, b1) - Math.min(a1, b1)
        );
    }

    public static int sumDist(String a, String b) {
        char a0 = a.charAt(0);
        char a1 = a.charAt(1);
        char b0 = b.charAt(0);
        char b1 = b.charAt(1);
        return
                (Math.max(a0, b0) - Math.min(a0, b0)) +
                        (Math.max(a1, b1) - Math.min(a1, b1))
        ;
    }

    public static boolean mate(String wk, String bk, String wc, String wv) {
        boolean check = forCamel.get(wc).contains(bk) || forVizir.get(wv).contains(bk);
        if (!check) return false;
        for (String escape : forKing.get(bk)) {
            if (!forKing.get(wk).contains(escape) && !forVizir.get(wv).contains(escape) && !forCamel.get(wc).contains(escape)) {
                return false;
            }
        }
        return true;
    }

    public static boolean stalemate(String wk, String bk, String wc, String wv) {
        boolean check = forCamel.get(wc).contains(bk) || forVizir.get(wv).contains(bk);
        for (String escape : forKing.get(bk)) {
            if (!forKing.get(wk).contains(escape) && !forVizir.get(wv).contains(escape) && !forCamel.get(wc).contains(escape)) {
                return false;
            }
        }
        return !check;
    }

    public static int eval(String wk, String bk, String wc, String wv, String t) {
        Stack<String> stack = new Stack<>();
        stack.push(wk + " " + bk + " " + wc + " " + wv + " " + t);
        while (!stack.isEmpty()) {
            String st = stack.peek();
            String[] line = st.split(" ");
            String wKing = line[0];
            String bKing = line[1];
            String wCamel = line[2];
            String wVizir = line[3];
            String turn = line[4];
            if (Objects.equals(turn, "w")) {
                if (seenWhite.containsKey(st)) {
                    stack.pop();
                    continue;
                }
                int ans = Integer.MAX_VALUE;
                boolean full = true;
                int kingDist = dist(wKing, bKing);
                for (String pos : forKing.get(wKing)) {
                    if (!Objects.equals(pos, wCamel) && !Objects.equals(pos, wVizir) && okKings(pos, bKing)) {
                        String ss = pos + " " + bKing + " " + wCamel + " " + wVizir;
                        if (seenBlack.containsKey(ss)) {
                            ans = Math.min(ans, addd(seenBlack.get(ss), 1));
                        } else if (!gotten.contains(ss + " b")) {
                            gotten.add(ss + " b");
                            full = false;
                            stack.push(ss + " b");
                        }
                    }
                }
                int camelDist = dist(wCamel, bKing);
                for (String pos : forCamel.get(wCamel)) {
                    if (!Objects.equals(pos, wKing) && !Objects.equals(pos, wVizir)) {
                        String ss = wKing + " " + bKing + " " + pos + " " + wVizir;
                        if (seenBlack.containsKey(ss)) {
                            ans = Math.min(ans, addd(seenBlack.get(ss), 1));
                        } else if (!gotten.contains(ss + " b")) {
                            gotten.add(ss + " b");
                            full = false;
                            stack.push(ss + " b");
                        }
                    }
                }
                int vizirDist = dist(wVizir, bKing);
                for (String pos : forVizir.get(wVizir)) {
                    if (!Objects.equals(pos, wKing) && !Objects.equals(pos, wCamel)) {
                        String ss = wKing + " " + bKing + " " + wCamel + " " + pos;
                        if (seenBlack.containsKey(ss)) {
                            ans = Math.min(ans, addd(seenBlack.get(ss), 1));
                        } else if (!gotten.contains(ss + " b")) {
                            gotten.add(ss + " b");
                            full = false;
                            stack.push(ss + " b");
                        }
                    }
                }
                if (full) {
                    seenWhite.put(wKing + " " + bKing + " " + wCamel + " " + wVizir, ans);
                    stack.pop();
                }
            } else {
                if (seenBlack.containsKey(st)) {
                    stack.pop();
                    continue;
                }
                if (mate(wKing, bKing, wCamel, wVizir)) {
                    seenBlack.put(st, 0);
                    stack.pop();
                    continue;
                }
                if (stalemate(wKing, bKing, wCamel, wVizir)) {
                    seenBlack.put(st, Integer.MAX_VALUE);
                    stack.pop();
                    continue;
                }
                int ans = 0;
                boolean full = true;
                boolean found = false;
                HashSet<String> news = new HashSet<>();
                for (String pos : forKing.get(bKing)) {
                    if (forCamel.get(wCamel).contains(pos)) continue;
                    if (forVizir.get(wVizir).contains(pos)) continue;
                    if (forKing.get(wKing).contains(pos)) continue;

                    if (Objects.equals(pos, wCamel) || Objects.equals(pos, wVizir)) {
                        ans = Integer.MAX_VALUE;
                        found = true;
                        break;
                    }

                    if (seenWhite.containsKey(wKing + " " + pos + " " + wCamel + " " + wVizir)) {
                        ans = Math.max(ans, seenWhite.get(wKing + " " + pos + " " + wCamel + " " + wVizir));
                    }

                    if (!gotten.contains(wKing + " " + pos + " " + wCamel + " " + wVizir + " w")) {
                        gotten.add(wKing + " " + pos + " " + wCamel + " " + wVizir + " w");
                        news.add(wKing + " " + pos + " " + wCamel + " " + wVizir + " w");
                        full = false;
                    }
                }
                if (full || found) {
                    seenBlack.put(wKing + " " + bKing + " " + wCamel + " " + wVizir, ans);
                    stack.pop();
                } else {
                    for (String nn : news) {
                        stack.push(nn);
                    }
                }
            }
        }
        if (Objects.equals(t, "w")) {
            return seenWhite.get(wk + " " + bk + " " + wc + " " + wv);
        } else {
            return seenBlack.get(wk + " " + bk + " " + wc + " " + wv);
        }
    }

    public static void main(String[] args) throws IOException {
        // Initialization

        for (int i = 0; i < 8; i++) {
            for (int j = 0; j < 8; j++) {
                String place = toPlace(i, j);
                forVizir.put(place, vizir(place));
                forCamel.put(place, camel(place));
                forKing.put(place, king(place));
            }
        }

        BufferedReader rd = new BufferedReader(new InputStreamReader(System.in));
        PrintWriter pw = new PrintWriter(System.out);
        int t = Integer.parseInt(rd.readLine());
        for (int i = 0; i < t; i++) {
            String[] line = rd.readLine().split(" ");
            String wKing = line[0];
            String bKing = line[1];
            String camel = line[2];
            String vizir = line[3];
            String turn = line[4];
            int evaluation = eval(wKing, bKing, camel, vizir, turn);
            if (evaluation == Integer.MAX_VALUE) {
                pw.println(0);
            } else {
                pw.println("#" + evaluation);
            }
        }
        pw.flush();
        pw.close();
    }
}