#include <iostream>
#include <vector>
#include <string>
#include <algorithm>

#define pb push_back

using ll = long long;
using namespace std;
using ii = pair<int,ll>;

int getRoot(int v, vector<int>& p) {
    int v0 = v;
    while (p[v] >= 0) {
        v = p[v];
    }
    int root = v;
    v = v0;
    while (p[v] >= 0) {
        int parent = p[v];
        p[v] = root;
        v = parent;
    }
    return root;
}
 
bool join(int a, int b, vector<int>& p) {
    a = getRoot(a, p); b = getRoot(b, p);
    if (a == b) return false;
    if (p[a] > p[b]) {
        swap(a, b);
    }
    p[a] += p[b];
    p[b] = a;
    return true;
}

struct Edge {
    ll w;
    int v1;
    int v2;
};

const int MAXN = 1e6 + 1;
const int LOGN = 20;

int up[MAXN][LOGN];
int depth[MAXN];
int way[MAXN];

void dfs(int v, vector<vector<ii>>& adj, vector<bool> &vis, int dpth) {
	vis[v] = true;
	for (int lg = 1; lg < LOGN; lg++) {
		up[v][lg] = up[up[v][lg - 1]][lg - 1];
	}
	depth[v] = ++dpth;
	for (auto [u,w] : adj[v]) {
		if (!vis[u]) {
			up[u][0] = v;
			way[u] = way[v] + w;
			dfs(u, adj, vis, dpth);
		}
	}
	return;
}

int lca(int v, int u) {
	if (depth[u] > depth[v]) swap(u, v);
	for (int lg = LOGN - 1; lg >= 0; lg--) {
		int nv = up[v][lg];
		if (depth[nv] >= depth[u]) {
			v = nv;
		}
	}
	if (v == u) return v;
	for (int lg = LOGN - 1; lg >= 0; lg--) {
		int nv = up[v][lg];
		int nu = up[u][lg];
		if (nv != nu) {
			v = nv;
			u = nu;
		}
	}
	return up[v][0];
}

int main()
{
    int nV;
    cin >> nV;
    vector<Edge> edges;
    for (int i = 0; i < nV; i++) {
        for (int j = 0; j < nV; j++) {
            ll w;
            cin >> w;
            edges.pb({w,i,j});
        }
    }
    sort(edges.begin(), edges.end(), [](const Edge &e1, const Edge &e2){
       return e1.w < e2.w; 
    });
    vector<int> p(nV, -1);
    vector<vector<ii>> lst(nV);
    for (Edge &e : edges) {
        if (join(e.v1,e.v2,p)) {
            lst[e.v1].pb({e.v2, e.w});
            lst[e.v2].pb({e.v1, e.w});
        }
    }
    vector<bool> vis(nV, false);
    dfs(0, lst, vis, 0);
    bool ans = true;
    for (Edge e : edges) {
        int l = lca(e.v1,e.v2);
        ans &= (e.w == (way[e.v1] - way[l]) + way[e.v2] - way[l]);
    }
    if (ans) {
        cout << "Yes";
    } else {
        cout << "No";
    }
    return 0;
}